"""Metadata for Authicola package."""
__title__ = 'drf_keycloak_auth'
__description__ = \
    'A convenience libary for authenticating users from Keycloak access tokens'
__url__ = 'https://gitlab.com/garyburgmann/drf-keycloak-auth'
__version__ = '0.0.1.dev0'
__author__ = 'Gary Burgmann'
__author_email__ = 'garyburgmann@gmail.com'
__license__ = 'MIT'



""" module for app specific keycloak connection """
from typing import Dict, List

from django.conf import settings
from keycloak import KeycloakOpenID


try:
    keycloak_openid = KeycloakOpenID(
        server_url=settings.KEYCLOAK_CONFIG['KEYCLOAK_SERVER_URL'],
        realm_name=settings.KEYCLOAK_CONFIG['KEYCLOAK_REALM'],
        client_id=settings.KEYCLOAK_CONFIG['KEYCLOAK_CLIENT_ID'],
        client_secret_key=(
            settings.KEYCLOAK_CONFIG['KEYCLOAK_CLIENT_SECRET_KEY']
        )
    )
except KeyError as e:
    raise KeyError(
        f'invalid settings.KEYCLOAK_CONFIG: {e}'
    )


def get_resource_roles(decoded_token: Dict) -> List[str]:
    # Get roles from access token
    resource_access_roles = []
    try:
        resource_access_roles = (
            decoded_token['resource_access']
            [settings.KEYCLOAK_CONFIG['KEYCLOAK_CLIENT_ID']]
            ['roles']
        )
        return [f'role:{x}' for x in resource_access_roles]
    except Exception as _:
        return []
